Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1151)

Unified Diff: tests/language_2/unresolved_top_level_var_test.dart

Issue 3008723002: Migrate block 163 to Dart 2.0. (Closed)
Patch Set: Merge fixups Created 3 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: tests/language_2/unresolved_top_level_var_test.dart
diff --git a/tests/language/unresolved_top_level_var_negative_test.dart b/tests/language_2/unresolved_top_level_var_test.dart
similarity index 64%
rename from tests/language/unresolved_top_level_var_negative_test.dart
rename to tests/language_2/unresolved_top_level_var_test.dart
index 589ddd5e6c1ddabf5de17631a9c54849d83a78b1..daf5305017ca3cd0d4ebc5ed04eafd957a9f2eb2 100644
--- a/tests/language/unresolved_top_level_var_negative_test.dart
+++ b/tests/language_2/unresolved_top_level_var_test.dart
@@ -2,11 +2,11 @@
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.
-// Test that an unresolved identifier at the top level does not crash
-// the parser.
+// Test that an unresolved identifier at the top level causes a compile-time
+// error.
-var a = b;
+var a = b; /*@compile-error=unspecified*/
main() {
print(a);
-}
+}
« no previous file with comments | « tests/language_2/unresolved_top_level_method_test.dart ('k') | tests/language_2/unsigned_right_shift_test.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698